@@ -229,7 +229,6 @@ class ConfArgParser(argparse.ArgumentParser):
 
             self.config_mapping[dest] = (section, name)
             self.dest_mapping[(section, name)] = (dest)
-
     def config2dest(self, config):
         args = {}
         for dest, (section, name) in self.config_mapping.items():
@@ -239,21 +238,22 @@ class ConfArgParser(argparse.ArgumentParser):
         return args
 
     def args2config(self, args=sys.argv[1:]):
-        args = self.parse_args(args)
+        args = argparse.ArgumentParser.parse_args(self, args)
         config = ConfigParser.RawConfigParser()
         sections = set()
         defaults_added = False
-
         for dest, (section, name) in self.config_mapping.items():
             try:
                 a = args.__getattribute__(dest)
-                if section not in sections and section.lower() != "defaults":
-                    config.add_section(section)
-                if section.lower() == "defaults" and not defaults_added:
-                    defaults_added = True
-                    config.add_section("defaults")
             except: continue
 
+            if section not in sections and section.lower() != "defaults":
+                config.add_section(section)
+                sections.add(section)
+            if section.lower() == "defaults" and not defaults_added:
+                defaults_added = True
+                config.add_section("defaults")
+
             if a == None: config.set(section, name, "")
             else: config.set(section, name, _repr(a))
 
